# Invite the new admin to register their machine with the Linux Counter:
if [ ! -f var/spool/mail/root ]; then
 mv var/spool/mail/root.new var/spool/mail/root
else
 cat var/spool/mail/root.new >> var/spool/mail/root
 rm var/spool/mail/root.new
fi
# These links have historically been part of the Linux libc package, but they
# aren't created by glibc2.  We'll make sure they're made here rather than
# add them to the glibc2 package:
( cd usr/include ; rm -rf linux )
( cd usr/include ; ln -sf /usr/src/linux/include/linux linux )
( cd usr/include ; rm -rf asm )
( cd usr/include ; ln -sf /usr/src/linux/include/asm asm )
# Do that symlink thing:
( cd usr/man ; rm -rf cat1 )
( cd usr/man ; ln -sf /var/man/cat1 cat1 )
( cd usr/man ; rm -rf cat2 )
( cd usr/man ; ln -sf /var/man/cat2 cat2 )
( cd usr/man ; rm -rf cat3 )
( cd usr/man ; ln -sf /var/man/cat3 cat3 )
( cd usr/man ; rm -rf cat4 )
( cd usr/man ; ln -sf /var/man/cat4 cat4 )
( cd usr/man ; rm -rf cat5 )
( cd usr/man ; ln -sf /var/man/cat5 cat5 )
( cd usr/man ; rm -rf cat6 )
( cd usr/man ; ln -sf /var/man/cat6 cat6 )
( cd usr/man ; rm -rf cat7 )
( cd usr/man ; ln -sf /var/man/cat7 cat7 )
( cd usr/man ; rm -rf cat8 )
( cd usr/man ; ln -sf /var/man/cat8 cat8 )
( cd usr/man ; rm -rf cat9 )
( cd usr/man ; ln -sf /var/man/cat9 cat9 )
( cd usr/man ; rm -rf catn )
( cd usr/man ; ln -sf /var/man/catn catn )
( cd usr/openwin/man ; rm -rf cat1 )
( cd usr/openwin/man ; ln -sf /var/man/cat1 cat1 )
( cd usr/openwin/man ; rm -rf cat2 )
( cd usr/openwin/man ; ln -sf /var/man/cat2 cat2 )
( cd usr/openwin/man ; rm -rf cat3 )
( cd usr/openwin/man ; ln -sf /var/man/cat3 cat3 )
( cd usr/openwin/man ; rm -rf cat4 )
( cd usr/openwin/man ; ln -sf /var/man/cat4 cat4 )
( cd usr/openwin/man ; rm -rf cat5 )
( cd usr/openwin/man ; ln -sf /var/man/cat5 cat5 )
( cd usr/openwin/man ; rm -rf cat6 )
( cd usr/openwin/man ; ln -sf /var/man/cat6 cat6 )
( cd usr/openwin/man ; rm -rf cat7 )
( cd usr/openwin/man ; ln -sf /var/man/cat7 cat7 )
( cd usr/openwin/man ; rm -rf cat8 )
( cd usr/openwin/man ; ln -sf /var/man/cat8 cat8 )
( cd usr/openwin/man ; rm -rf cat9 )
( cd usr/openwin/man ; ln -sf /var/man/cat9 cat9 )
( cd usr/openwin/man ; rm -rf catn )
( cd usr/openwin/man ; ln -sf /var/man/catn catn )
( cd usr/X11R6/lib ; rm -rf X11 )
( cd usr/X11R6/lib ; ln -sf /var/X11R6/lib X11 )
( cd usr/X11R6/bin ; rm -rf X )
( cd usr/X11R6/bin ; ln -sf /var/X11R6/bin/X X )
( cd usr/X11R6/man ; rm -rf cat1 )
( cd usr/X11R6/man ; ln -sf /var/man/cat1 cat1 )
( cd usr/X11R6/man ; rm -rf cat2 )
( cd usr/X11R6/man ; ln -sf /var/man/cat2 cat2 )
( cd usr/X11R6/man ; rm -rf cat3 )
( cd usr/X11R6/man ; ln -sf /var/man/cat3 cat3 )
( cd usr/X11R6/man ; rm -rf cat4 )
( cd usr/X11R6/man ; ln -sf /var/man/cat4 cat4 )
( cd usr/X11R6/man ; rm -rf cat5 )
( cd usr/X11R6/man ; ln -sf /var/man/cat5 cat5 )
( cd usr/X11R6/man ; rm -rf cat6 )
( cd usr/X11R6/man ; ln -sf /var/man/cat6 cat6 )
( cd usr/X11R6/man ; rm -rf cat7 )
( cd usr/X11R6/man ; ln -sf /var/man/cat7 cat7 )
( cd usr/X11R6/man ; rm -rf cat8 )
( cd usr/X11R6/man ; ln -sf /var/man/cat8 cat8 )
( cd usr/X11R6/man ; rm -rf cat9 )
( cd usr/X11R6/man ; ln -sf /var/man/cat9 cat9 )
( cd usr/X11R6/man ; rm -rf catn )
( cd usr/X11R6/man ; ln -sf /var/man/catn catn )
( cd usr ; rm -rf adm )
( cd usr ; ln -sf /var/adm adm )
( cd usr ; rm -rf spool )
( cd usr ; ln -sf /var/spool spool )
( cd usr ; rm -rf tmp )
( cd usr ; ln -sf /var/tmp tmp )
( cd var ; rm -rf rwho )
( cd var ; ln -sf /var/spool/rwho rwho )
( cd var ; rm -rf adm )
( cd var ; ln -sf log adm )
( cd bin ; rm -rf sh )
( cd bin ; ln -sf bash sh )
( cd var ; rm -rf mail )
( cd var ; ln -sf spool/mail mail )
